Module live_wrap

Module live_wrap 

Structs

Row
A single visual row produced by RowBuilder.
RowBuilder
Incrementally wraps input text into visual rows of at most width cells.

Functions

take_prefix_by_width
Take a prefix of text whose visible width is at most max_cols. Returns (prefix, suffix, prefix_width).