word_wrap_lines

Function word_wrap_lines 

pub fn word_wrap_lines<'a, I, O, L>(
    lines: I,
    width_or_options: O,
) -> Vec<Line<'static>>
where I: IntoIterator<Item = L>, L: IntoLineInput<'a>, O: Into<RtOptions<'a>>,
Wrap a sequence of lines, applying the initial indent only to the very first output line, and using the subsequent indent for all later wrapped pieces.