pub struct RtOptions<'a> {
pub width: usize,
pub line_ending: LineEnding,
pub initial_indent: Line<'a>,
pub subsequent_indent: Line<'a>,
pub break_words: bool,
pub wrap_algorithm: WrapAlgorithm,
pub word_separator: WordSeparator,
pub word_splitter: WordSplitter,
}Fields
width: usizeThe width in columns at which the text will be wrapped.
line_ending: LineEndingLine ending used for breaking lines.
initial_indent: Line<'a>Indentation used for the first line of output. See the
Options::initial_indent method.
subsequent_indent: Line<'a>Indentation used for subsequent lines of output. See the
Options::subsequent_indent method.
break_words: boolAllow long words to be broken if they cannot fit on a line.
When set to false, some lines may be longer than
self.width. See the Options::break_words method.
wrap_algorithm: WrapAlgorithmWrapping algorithm to use, see the implementations of the
[WrapAlgorithm] trait for details.
word_separator: WordSeparatorThe line breaking algorithm to use, see the WordSeparator
trait for an overview and possible implementations.
word_splitter: WordSplitterThe method for splitting words. This can be used to prohibit splitting words on hyphens, or it can be used to implement language-aware machine hyphenation.
Implementations
Sourceimpl<'a> RtOptions<'a>
impl<'a> RtOptions<'a>
pub fn new(width: usize) -> Self
pub fn line_ending(self, line_ending: LineEnding) -> Self
pub fn width(self, width: usize) -> Self
pub fn initial_indent(self, initial_indent: Line<'a>) -> Self
pub fn subsequent_indent(self, subsequent_indent: Line<'a>) -> Self
pub fn break_words(self, break_words: bool) -> Self
pub fn word_separator(self, word_separator: WordSeparator) -> RtOptions<'a>
pub fn wrap_algorithm(self, wrap_algorithm: WrapAlgorithm) -> RtOptions<'a>
pub fn word_splitter(self, word_splitter: WordSplitter) -> RtOptions<'a>