pub struct FrameRequester { /* private fields */ }Expand description
A requester for scheduling future frame draws on the TUI event loop.
This is the handler side of an actor/handler pair with FrameScheduler, which coalesces
multiple frame requests into a single draw operation.
Clones of this type can be freely shared across tasks to make it possible to trigger frame draws from anywhere in the TUI code.
Implementations
Sourceimpl FrameRequester
impl FrameRequester
Sourcepub fn new(draw_tx: Sender<()>) -> Self
pub fn new(draw_tx: Sender<()>) -> Self
Create a new FrameRequester and spawn its associated FrameScheduler task.
The provided draw_tx is used to notify the TUI event loop of scheduled draws.
Sourcepub fn schedule_frame(&self)
pub fn schedule_frame(&self)
Schedule a frame draw as soon as possible.
Sourcepub fn schedule_frame_in(&self, dur: Duration)
pub fn schedule_frame_in(&self, dur: Duration)
Schedule a frame draw to occur after the specified duration.